@@ -101,6 +101,9 @@ class KeycloakAdmin:
         # Get token Admin
         self.get_token()
 
+    def close(self):
+        if self._connection:
+            self._connection.close()
 
     @property
     def server_url(self):
